==> Maxy-0.1.4.0-src.zip: Maxy/MAXY/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by MAXY.rc
//
#define IDC_MARGIN                      100
#define IDC_FINGER                      101
#define IDR_MAINFRAME                   128
#define IDD_ABOUTBOX                    130
#define IDD_JUMP                        131
#define IDD_PROPERTY                    132
#define IDD_CUSTOMIZE_PROPPAGE_FILE     134
#define IDD_CUSTOMIZE_PROPPAGE_DISPLAY  135
#define IDD_CUSTOMIZE_PROPPAGE_OTHER    136
#define IDB_TOOLBAR_XP                  250
#define IDB_TOOLBAR_XP_HOT              251
#define IDB_TOOLBAR_XP_DISABLED         252
#define IDS_FILENAME_DEFAULT            300
#define IDS_STATUS_IDLE                 301
#define IDS_STATUS_INDICATOR_READONLY   302
#define IDS_STATUS_INDICATOR_OVERWRITE  303
#define IDS_FILTER_ALLFILES             310
#define IDS_ABOUT_DESCRIPTION           350
#define IDS_MSGBOX_INITFAILED           400
#define IDS_MSGBOX_ASKTOSAVE            401
#define IDS_MSGBOX_ASKTORELOAD          402
#define IDS_MSGBOX_NOINTERFACE_OPEN     403
#define IDS_MSGBOX_NOINTERFACE_SAVE     404
#define IDS_PROPERTY_CATEGORY_BASIC     500
#define IDS_PROPERTY_CATEGORY_FILE      501
#define IDS_PROPERTY_CATEGORY_FILE_BACKUP 502
#define IDS_PROPERTY_CATEGORY_FILE_AUTOSAVE 503
#define IDS_PROPERTY_CATEGORY_DISPLAY   504
#define IDS_PROPERTY_CATEGORY_DISPLAY_EMPHASIS 505
#define IDS_PROPERTY_CATEGORY_DISPLAY_PRINT 506
#define IDS_CAPTION_CUSTOMIZE           600
#define IDS_COMBO_CUSTOMIZE_EXCLUSION_NONE 650
#define IDS_COMBO_CUSTOMIZE_EXCLUSION_DISABLEWRITE 651
#define IDS_COMBO_CUSTOMIZE_EXCLUSION_DISABLEREADWRITE 652
#define IDC_JUMP_LINENUMBER             4100
#define IDC_JUMP_LINENUMBER_SPIN        4101
#define IDC_PROPERTY_TREE               4201
#define IDC_PROPERTY_GROUP              4202
#define IDC_PROPERTY_BASIC_IME          4210
#define IDC_PROPERTY_DISPLAY_LINENUMBER 4220
#define IDC_PROPERTY_DISPLAY_RULER      4221
#define IDC_PROPERTY_DISPLAY_UNDERLINE  4222
#define IDC_CUSTOMIZE_TAB               4300
#define IDC_CUSTOMIZE_FILE_CHECKTIMESTAMPONACTIVE 4301
#define IDC_CUSTOMIZE_FILE_OPENBYTHISFRAME 4302
#define IDC_CUSTOMIZE_FILE_STATIC_EXCLUTION 4303
#define IDC_CUSTOMIZE_FILE_EXCLUSION    4304
#define IDC_CUSTOMIZE_DISPLAY_RESTOREPLACEMENT 4310
#define IDC_CUSTOMIZE_DISPLAY_DISPLAYFULLPATHONACTIVE 4311
#define IDC_CUSTOMIZE_DISPLAY_DISPLAYFULLPATHONINACTIVE 4312
#define IDC_CUSTOMIZE_OTHER_BACKUPWHENCRUSHED 4320
#define IDC_ABOUT_STATIC_URL            4500
#define IDC_ABOUT_DESCRIPTION           4501
#define IDM_FILE_NEW                    40000
#define IDM_FILE_OPEN                   40001
#define IDM_FILE_SAVE                   40002
#define IDM_FILE_SAVE_AS                40003
#define IDM_FILE_SAVE_ALL               40004
#define IDM_FILE_PRINT                  40010
#define IDM_FILE_PRINT_PREVIEW          40011
#define IDM_FILE_CLOSE                  40020
#define IDM_FILE_CLOSE_ALL              40021
#define IDM_EDIT_UNDO                   41000
#define IDM_EDIT_REDO                   41001
#define IDM_EDIT_CUT                    41002
#define IDM_EDIT_COPY                   41003
#define IDM_EDIT_PASTE                  41004
#define IDM_EDIT_CLEAR                  41005
#define IDM_EDIT_RECONVERT              41010
#define IDM_EDIT_JUMP                   41020
#define IDM_EDIT_READONLY               41030
#define IDM_VIEW_BAR_TOOLBAR            42000
#define IDM_VIEW_BAR_STATUSBAR          42001
#define IDM_VIEW_TOPMOST                42010
#define IDM_SETTING_CHANGE_NONE         43000
#define IDM_SETTING_CHANGE_CREATE       43100
#define IDM_SETTING_PROPERTY            43101
#define IDM_SETTING_CUSTOMIZE           43102
#define IDM_HELP_INDEX                  44000
#define IDM_HELP_KEYWORD                44001
#define IDM_HELP_FINDER                 44002
#define IDM_HELP_WEBPAGE                44003
#define IDM_HELP_ABOUT                  44004
#define IDS_SC_SIZE                     61440
#define IDS_SC_MOVE                     61456
#define IDS_SC_MINIMIZE                 61472
#define IDS_SC_MAXIMIZE                 61488
#define IDS_SC_NEXTWINDOW               61504
#define IDS_SC_PREVWINDOW               61520
#define IDS_SC_CLOSE                    61536
#define IDS_SC_RESTORE                  61728

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        117
#define _APS_NEXT_COMMAND_VALUE         40054
#define _APS_NEXT_CONTROL_VALUE         1038
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> Maxy-0.1.5.0-src.zip: Maxy/MAXY/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by MAXY.rc
//
#define IDC_MARGIN                      100
#define IDC_FINGER                      101
#define IDR_MAINFRAME                   128
#define IDD_NOTIFYBACKUP                130
#define IDD_ABOUTBOX                    131
#define IDD_JUMP                        132
#define IDD_PROPERTY                    133
#define IDD_CUSTOMIZE_PROPPAGE_FILE     134
#define IDD_CUSTOMIZE_PROPPAGE_DISPLAY  135
#define IDD_CUSTOMIZE_PROPPAGE_OTHER    136
#define IDB_TOOLBAR_XP                  250
#define IDB_TOOLBAR_XP_HOT              251
#define IDB_TOOLBAR_XP_DISABLED         252
#define IDS_FILENAME_DEFAULT            300
#define IDS_STATUS_IDLE                 301
#define IDS_STATUS_INDICATOR_READONLY   302
#define IDS_STATUS_INDICATOR_OVERWRITE  303
#define IDS_FILTER_ALLFILES             310
#define IDS_ABOUT_DESCRIPTION           350
#define IDS_MSGBOX_INITFAILED           400
#define IDS_MSGBOX_ASKTOSAVE            401
#define IDS_MSGBOX_ASKTORELOAD          402
#define IDS_MSGBOX_NOINTERFACE_OPEN     403
#define IDS_MSGBOX_NOINTERFACE_SAVE     404
#define IDS_PROPERTY_CATEGORY_BASIC     500
#define IDS_PROPERTY_CATEGORY_FILE      501
#define IDS_PROPERTY_CATEGORY_FILE_BACKUP 502
#define IDS_PROPERTY_CATEGORY_FILE_AUTOSAVE 503
#define IDS_PROPERTY_CATEGORY_DISPLAY   504
#define IDS_PROPERTY_CATEGORY_DISPLAY_EMPHASIS 505
#define IDS_PROPERTY_CATEGORY_DISPLAY_PRINT 506
#define IDS_CAPTION_CUSTOMIZE           600
#define IDS_COMBO_CUSTOMIZE_EXCLUSION_NONE 650
#define IDS_COMBO_CUSTOMIZE_EXCLUSION_DISABLEWRITE 651
#define IDS_COMBO_CUSTOMIZE_EXCLUSION_DISABLEREADWRITE 652
#define IDC_NOTIFYBACKUP_FILELIST       4000
#define IDC_NOTIFYBACKUP_OPEN           4001
#define IDC_NOTIFYBACKUP_OPEN_ALL       4002
#define IDC_JUMP_LINENUMBER             4100
#define IDC_JUMP_LINENUMBER_SPIN        4101
#define IDC_PROPERTY_TREE               4201
#define IDC_PROPERTY_GROUP              4202
#define IDC_PROPERTY_BASIC_IME          4210
#define IDC_PROPERTY_DISPLAY_LINENUMBER 4220
#define IDC_PROPERTY_DISPLAY_RULER      4221
#define IDC_PROPERTY_DISPLAY_UNDERLINE  4222
#define IDC_CUSTOMIZE_TAB               4300
#define IDC_CUSTOMIZE_FILE_CHECKTIMESTAMPONACTIVE 4301
#define IDC_CUSTOMIZE_FILE_OPENBYTHISFRAME 4302
#define IDC_CUSTOMIZE_FILE_STATIC_EXCLUTION 4303
#define IDC_CUSTOMIZE_FILE_EXCLUSION    4304
#define IDC_CUSTOMIZE_DISPLAY_RESTOREPLACEMENT 4310
#define IDC_CUSTOMIZE_DISPLAY_DISPLAYFULLPATHONACTIVE 4311
#define IDC_CUSTOMIZE_DISPLAY_DISPLAYFULLPATHONINACTIVE 4312
#define IDC_CUSTOMIZE_OTHER_BACKUPWHENCRUSHED 4320
#define IDC_CUSTOMIZE_OTHER_BACKUPPREFIX 4321
#define IDC_ABOUT_STATIC_URL            4500
#define IDC_ABOUT_DESCRIPTION           4501
#define IDM_FILE_NEW                    40000
#define IDM_FILE_OPEN                   40001
#define IDM_FILE_SAVE                   40002
#define IDM_FILE_SAVE_AS                40003
#define IDM_FILE_SAVE_ALL               40004
#define IDM_FILE_PRINT                  40010
#define IDM_FILE_PRINT_PREVIEW          40011
#define IDM_FILE_CLOSE                  40020
#define IDM_FILE_CLOSE_ALL              40021
#define IDM_EDIT_UNDO                   41000
#define IDM_EDIT_REDO                   41001
#define IDM_EDIT_CUT                    41002
#define IDM_EDIT_COPY                   41003
#define IDM_EDIT_PASTE                  41004
#define IDM_EDIT_CLEAR                  41005
#define IDM_EDIT_RECONVERT              41010
#define IDM_EDIT_JUMP                   41020
#define IDM_EDIT_READONLY               41030
#define IDM_VIEW_BAR_TOOLBAR            42000
#define IDM_VIEW_BAR_STATUSBAR          42001
#define IDM_VIEW_TOPMOST                42010
#define IDM_SETTING_CHANGE_NONE         43000
#define IDM_SETTING_CHANGE_CREATE       43100
#define IDM_SETTING_PROPERTY            43101
#define IDM_SETTING_CUSTOMIZE           43102
#define IDM_HELP_INDEX                  44000
#define IDM_HELP_KEYWORD                44001
#define IDM_HELP_FINDER                 44002
#define IDM_HELP_WEBPAGE                44003
#define IDM_HELP_ABOUT                  44004
#define IDS_SC_SIZE                     61440
#define IDS_SC_MOVE                     61456
#define IDS_SC_MINIMIZE                 61472
#define IDS_SC_MAXIMIZE                 61488
#define IDS_SC_NEXTWINDOW               61504
#define IDS_SC_PREVWINDOW               61520
#define IDS_SC_CLOSE                    61536
#define IDS_SC_RESTORE                  61728

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        118
#define _APS_NEXT_COMMAND_VALUE         40054
#define _APS_NEXT_CONTROL_VALUE         1045
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
